@@ -1,5 +1,4 @@
 
-import six
 
 from ..imath import main
 
@@ -15,4 +14,4 @@ def test_imath_works(capsys):
     out, err = capsys.readouterr()
     # out = out.split("\n")
     # out.sort()
-    assert isinstance(out, six.text_type)
+    assert isinstance(out, str)
